<?php

declare(strict_types=1);

namespace Drupal\private_message\Plugin\EntityReferenceSelection;

use Drupal\Core\Entity\Attribute\EntityReferenceSelection;
use Drupal\Core\Entity\Query\QueryInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\user\Plugin\EntityReferenceSelection\UserSelection;

/**
 * Provides reference selection for not blocked users.
 */
#[EntityReferenceSelection(
  id: "private_message:not_blocked_user",
  label: new TranslatableMarkup("Not blocked user selection"),
  group: "private_message",
  weight: 3,
  entity_types: ["user"]
)]
class NotBlockedUserSelection extends UserSelection {

  /**
   * {@inheritdoc}
   */
  protected function buildEntityQuery($match = NULL, $match_operator = 'CONTAINS'): QueryInterface {
    $query = parent::buildEntityQuery($match, $match_operator);

    $subquery = $this->connection->select('private_message_ban', 'pmb')
      ->fields('pmb', ['target']);
    $subquery->condition('owner', $this->currentUser->id());

    $query->condition('uid', $subquery, 'NOT IN');

    return $query;
  }

}
