<?php

declare(strict_types=1);

namespace Drupal\Tests\private_message\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\private_message\Traits\PrivateMessageTestTrait;

/**
 * Tests for the Private Message Notification.
 *
 * @group private_message
 */
class PrivateMessageNotificationTest extends BrowserTestBase {

  use PrivateMessageTestTrait;

  /**
   * {@inheritdoc}
   */

  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['block', 'private_message_test'];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->attachFullNameField();
    $this->createTestingUsers();
    $this->drupalPlaceBlock('private_message_notification_block');
  }

  /**
   * Tests that the receiving user gets a notification.
   */
  public function testUserReceivesNotification(): void {
    $this->drupalLogin($this->users['a']);

    $this->drupalGet('/private-message/create');
    $this->assertSession()->statusCodeEquals(200);
    $this->submitForm([
      'members[0][target_id]' => $this->users['b']->getAccountName(),
      'message[0][value]' => $this->getRandomGenerator()->sentences(5),
    ], 'Send');
    $this->assertSession()->statusCodeEquals(200);

    $this->drupalLogin($this->users['b']);
    $this->drupalGet('private-message/create');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->elementTextContains('css', 'a.private-message-page-link', '1');
  }

}
