<?php

declare(strict_types=1);

namespace Drupal\Tests\private_message\Traits;

use Drupal\Tests\user\Traits\UserCreationTrait;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;

/**
 * Reusable test code.
 */
trait PrivateMessageTestTrait {

  use UserCreationTrait;

  /**
   * Testing users.
   *
   * @var array<string, \Drupal\user\UserInterface>
   */
  protected array $users = [];

  /**
   * Creates testing users.
   *
   * @param int $amount
   *   (optional) Amount of users to be created. Defaults to 2.
   */
  protected function createTestingUsers(int $amount = 2): void {
    $keys = array_map(fn(int $i): string => chr($i + 96), range(1, $amount));
    $randomGenerator = $this->getRandomGenerator();

    foreach ($keys as $key) {
      $firstName = ucfirst($randomGenerator->word(rand(5, 9)));
      $lastName = ucfirst($randomGenerator->word(rand(5, 9)));
      $values = FieldConfig::loadByName(
        'user',
        'user',
        'full_name'
      ) ? ['full_name' => "$firstName $lastName"] : [];

      $this->users[$key] = $this->createUser([
        'use private messaging system',
        'access user profiles',
      ], NULL, FALSE, $values);
    }
  }

  /**
   * Adds a full_name field to the user entity.
   */
  protected function attachFullNameField(): void {
    FieldStorageConfig::create([
      'entity_type' => 'user',
      'type' => 'string',
      'field_name' => 'full_name',
    ])->save();
    FieldConfig::create([
      'entity_type' => 'user',
      'bundle' => 'user',
      'field_name' => 'full_name',
    ])->save();
  }

}
